@@ -1,9 +1,11 @@
 #!/usr/bin/env python
 
 from .finder import CustomAction, Finder, Layout, InfoStyle, DEFAULT_POINTER, DEFAULT_PROMPT, DEFAULT_HEADER
-from typing import Any, Callable, Dict, Iterator, Optional, Sequence, Union
+from .keys import KeysBinding
+from .matcher import Matcher, ExtendedMatcher
+from typing import Any, Callable, Iterator, Optional, Sequence, Type, Union
 
-__version__ = "0.0.9"
+__version__ = "0.0.10"
 "PZP Version"
 
 __all__ = ["pzp", "CustomAction"]
@@ -19,7 +21,8 @@ def pzp(
     pointer_str: str = DEFAULT_POINTER,
     prompt_str: str = DEFAULT_PROMPT,
     header_str: str = DEFAULT_HEADER,
-    actions: Optional[Dict[str, Sequence[str]]] = None,
+    keys_binding: Optional[KeysBinding] = None,
+    matcher: Union[Matcher, Type[Matcher]] = ExtendedMatcher,
     input: Optional[str] = None,
 ) -> Any:
     """
@@ -39,7 +42,8 @@ def pzp(
         pointer_str: Pointer to the current line
         prompt_str: Input prompt
         header_str: Header
-        actions: Custom key binding
+        keys_binding: Custom keys binding
+        matcher: Matcher
 
     Returns:
         item: the selected item
@@ -54,6 +58,7 @@ def pzp(
         pointer_str=pointer_str,
         prompt_str=prompt_str,
         header_str=header_str,
-        actions=actions,
+        keys_binding=keys_binding,
+        matcher=matcher,
     )
     return finder.show(input=input)
