@@ -31,7 +31,7 @@ class FakeTerminal:
         return "\n".join(self.screen.display)
 
 
-def test_screen():
+def test_screen_movements():
     terminal = FakeTerminal()
     screen = Screen(stream=terminal.output_stream, fullscreen=True, height=24)
     assert terminal.cursor.y == 0
@@ -61,6 +61,27 @@ def test_screen():
     assert terminal.cursor.x == 0
 
 
+def test_screen():
+    terminal = FakeTerminal()
+    screen = Screen(stream=terminal.output_stream, fullscreen=True, height=24)
+    assert terminal.cursor.x == 0
+    assert terminal.cursor.y == 0
+    screen.space(10).flush()
+    assert terminal.cursor.x == 10
+    assert terminal.cursor.y == 0
+    screen.nl(10).flush()
+    assert terminal.cursor.x == 0
+    assert terminal.cursor.y == 10
+    screen.space().flush()
+    assert terminal.cursor.x == 1
+    assert terminal.cursor.y == 10
+    screen.nl().flush()
+    assert terminal.cursor.x == 0
+    assert terminal.cursor.y == 11
+    screen.space(10).erase_line().flush()
+    assert terminal.cursor.x == 10
+
+
 def test_term():
     terminal = FakeTerminal()
     output_stream = terminal.output_stream
